#version 150

invariant in vec3 position_out_vs;
invariant in vec3 ambient_color_out_vs;
invariant in vec3 diffuse_color_out_vs;
invariant in vec3 normal_out_vs;
invariant in vec2 uvcoords_out_vs;
invariant in vec3 tangent_out_vs;

out vec4 normals_matid;
out vec4 albedo;
out vec4 depth;
out vec4 distort_spec;
out vec4 ambient;

uniform vec3 ambient_color_constant;
uniform vec3 diffuse_color_constant;
uniform vec2 gloss_specpower_constant;
uniform vec2 uv_offset;

uniform sampler2D diffuse_tex;
uniform sampler2D normalmap_tex;
uniform sampler2D gloss_specpower_tex;

vec3 encode(vec3 n);

void main(void)
{
	vec2 uvcoords = uvcoords_out_vs + uv_offset;
	vec3 diffuse_texel = texture2D(diffuse_tex, uvcoords).rgb;
	vec3 normalmap_texel = texture2D(normalmap_tex, uvcoords).rgb;
	vec2 gloss_specpower_texel = texture2D(gloss_specpower_tex, uvcoords).rg;

	diffuse_texel = pow(diffuse_texel, vec3(1,1,1)*2.2);
	vec3 acol = diffuse_color_out_vs * diffuse_texel * diffuse_color_constant;

	normals_matid = vec4(encode(normalize(normal_out_vs)), 1.0);
	albedo = vec4(acol, 0.0);
	depth = vec4(length(position_out_vs), 0.0, 0.0, 0.0);
	distort_spec = vec4(0.5, 0.5, gloss_specpower_texel * gloss_specpower_constant);
	ambient = vec4(ambient_color_out_vs * ambient_color_constant * acol, 0.0);
}

